function [Flutter] = SetFlutterDist(PlantData,DistParam);
% SetFlutterDist
% Set flutter disturbance in time and frequency domain
% Ver.1.0, 2006-06-06 created by M.Hirata
% Copyright (c) 2004-2006, MSS benchmark working group

% Read parameters
AmpFlutterDist     = DistParam.AmpFlutterDist;
FlutterFreq        = DistParam.FlutterFreq;
FlutterFreqZeta    = DistParam.FlutterFreqZeta;
num_servo          = PlantData.num_servo;
num_sim_revolution = DistParam.num_sim_revolution;
Ts                 = PlantData.Ts; % PES Sampling
Tc                 = PlantData.Tc; % Controller output sampling
Tu                 = PlantData.Tu; % Plant input
Ty                 = PlantData.Ty; % Plant output
% Seeds for random signal
Seed_FlutterDist  = DistParam.Seed_FlutterDist;
% Frequency vector is defined by PES sampling frequency
Freq = DistParam.Freqs;
NUM  = DistParam.Nums;

% sys_FlutterNoise
lg = length(AmpFlutterDist);
for ii=1:lg
    w_f    = 2*pi*FlutterFreq(ii);
    zeta_f = FlutterFreqZeta(ii);
    pk_f   = AmpFlutterDist(ii);
    sys_FlutterDist(ii) = tf( pk_f*2*zeta_f*w_f^2,[1 2*zeta_f*w_f w_f^2] );
end

% Flutter dist. in time domain
if fix(Ts/Ty) ~= (Ts/Ty)
    error('Ts/Ty must be integer');
end
NUM_FlutterDist = num_servo*num_sim_revolution; % Ver.2.0
randn('state',Seed_FlutterDist);
Dist  = zeros(NUM_FlutterDist,1);
DistT = (0:NUM_FlutterDist-1)'*Ty; % Ver.2.0
for ii=1:lg
    sys_FlutterDist0 = sys_FlutterDist(ii);
    FlutterDistIn = whitenoise(NUM_FlutterDist,Ty); % Ver.2.0
    Dist = Dist + lsim(sys_FlutterDist0,FlutterDistIn,DistT);
end
dcidx       = 1:(Ts/Ty):NUM_FlutterDist;
DistAtPes   = Dist(dcidx); % down sampling by (Ts/Ty)
DistAtPesT  = (0:length(DistAtPes)-1)'*Ts;
DistAtPesTs = Ts;

% Flutter dist in frequency domain
Spec2 = zeros(NUM,1);
for ii=1:lg
    [mag,phs] = bode(sys_FlutterDist(ii), 2*pi*Freq );
    Spec2 = Spec2 + mag(:).^2;
end
Spec  = sqrt( Spec2 );

% Output parameters in time domain
Flutter.Dist        = Dist;
Flutter.DistT       = DistT;
Flutter.DistTs      = Ty;
Flutter.DistAtPes   = DistAtPes;
Flutter.DistAtPesT  = DistAtPesT;
Flutter.DistAtPesTs = DistAtPesTs;
% Output parameters in frequency domain
Flutter.Freq        = Freq;
Flutter.Spec        = Spec;

%% EOF of SetFlutterDist.m
