function [Force] = SetForceDist(PlantData,DistParam);
% SetForceDist
% Set force disturbance in time and frequency domain
% Ver.1.0, 2006-06-06 created by M.Hirata
% Copyright (c) 2004-2006, MSS benchmark working group

% Read parameters
AmpForceDist       = DistParam.AmpForceDist;
num_servo          = PlantData.num_servo;
num_sim_revolution = DistParam.num_sim_revolution;
Ts                 = PlantData.Ts; % PES Sampling
Tc                 = PlantData.Tc; % Controller output sampling
Tu                 = PlantData.Tu; % Plant input
Ty                 = PlantData.Ty; % Plant output
% Seeds for random signal
Seed_ForceDist  = DistParam.Seed_ForceDist;
% Frequency vector is defined by PES sampling frequency
Freq = DistParam.Freqs;
NUM  = DistParam.Nums;

% Force dist. in time domain
if fix(Ts/Tu) ~= (Ts/Tu)
    error('Ts/Tu must be integer');
end
NUM_ForceDist = num_servo*num_sim_revolution*(Ts/Tu);
randn('state',Seed_ForceDist);
Dist       = whitenoise(NUM_ForceDist,Tu)*DistParam.AmpForceDist;
DistT      = (0:NUM_ForceDist-1)'*Tu;
% dist at PES
DistOut    = lsim(PlantData.sys_Pn,Dist,DistT);
dcidx      = 1:(Ts/Tu):NUM_ForceDist;
DistAtPes  = DistOut(dcidx); % down sampling by (Ts/Tu)
DistAtPesT = (0:length(DistAtPes)-1)'*Ts;

% Force dist. in frequency domain
Spec      = DistParam.AmpForceDist*ones(NUM,1);
[mag,phs] = bode( PlantData.sys_Pn*DistParam.AmpForceDist, 2*pi*Freq );
SpecAtPes = mag(:);

% Output parameters in time domain
Force.Dist        = Dist;
Force.DistT       = DistT;
Force.DistTs      = Tu;
Force.DistAtPes   = DistAtPes;
Force.DistAtPesT  = DistAtPesT;
Force.DistAtPesTs = Ts;
% Output parameters in frequency domain
Force.Freq = Freq;
Force.Spec = Spec;
Force.SpecAtPes = SpecAtPes;

%% EOF of SetForceDist.m
