function [Sensor] = SetSensorNoise(PlantData,DistParam);
% SetSensorNoise
% Set sensor noise in time and frequency domain
% Ver.1.0, 2006-06-06 created by M.Hirata
% Copyright (c) 2004-2006, MSS benchmark working group

% simulation parameters
num_servo          = PlantData.num_servo;
num_sim_revolution = DistParam.num_sim_revolution;
Ts                 = PlantData.Ts; % PES Sampling
Tc                 = PlantData.Tc; % Controller output sampling
Tu                 = PlantData.Tu; % Plant input
Ty                 = PlantData.Ty; % Plant output
% seeds for random signal
Seed_SensorNoise  = DistParam.Seed_SensorNoise;

% Frequency vector is defined by PES sampling frequency
Freq = DistParam.Freqs;
NUM  = DistParam.Nums;

% Sensor noise in time domain
NUM_SensorNoise = num_servo*num_sim_revolution;
randn('state',Seed_SensorNoise);
Noise   = whitenoise(NUM_SensorNoise,Ts)*DistParam.AmpSensorNoise;
NoiseT  = (0:NUM_SensorNoise-1)'*Ts;

% Sensor noise in frequency domain
Spec = DistParam.AmpSensorNoise*ones(NUM,1);

% Output parameters in time domain
Sensor.Noise        = Noise;
Sensor.NoiseT       = NoiseT;
Sensor.NoiseTs      = Ts;
% Output parameters in frequency domain
Sensor.Freq        = Freq;
Sensor.Spec        = Spec;

%% EOF of SetSensorNoise.m
