% main.m
% Main m-script for hard disk benchmark problem
% M.Hirata
% Ver.1.0, 2005-04-26
% Ver.1.1, 2005-05-10, small fix
% Ver.1.2, 2005-05-16, small fix
% Ver.2.0, 2006-02-13, version up
% Ver.2.1, 2006-06-07, first release of Ver.2
% Copyright (c) 2004-2006, MSS benchmark working group

% clear all variables
clear

% Define hard disk model
options.seekmode = 0;              % 0 for track-following, 1 for track-seeking
PlantData  = SetPlantModel(options);
sys_Pn     = PlantData.sys_Pn;     % nominal model
sys_Pf     = PlantData.sys_Pf;     % full-order model
sys_Pfpert = PlantData.sys_Pfpert; % full-order model with parametric uncertainty

% Plot frequency response
f = logspace(1,5,500);
figure(1)
plot_bode(sys_Pn,f,1,1);
title('Nominal model')

figure(2)
plot_bode(sys_Pf,f,2,1);
title('Full-order model')

figure(3)
plot_bode(sys_Pfpert,f,3,1);
title('Full-order model w/ parametric variation')

% Set disturbance parameters
DistParam = SetDistParam(PlantData);
% DistParam.num_sim_revolution = 100; % save simulation time

% Disturbance
Force   = SetForceDist(PlantData,DistParam);
Flutter = SetFlutterDist(PlantData,DistParam);
Sensor  = SetSensorNoise(PlantData,DistParam);
RRO     = SetRRO(PlantData,DistParam);

% Disturbance and Noise in freqency domain
f        = DistParam.Freqs;
NRROSpec = sqrt(Force.SpecAtPes.^2 + Flutter.Spec.^2 + Sensor.Spec.^2);
SpecALL  = sqrt(NRROSpec.^2 + RRO.Spec.^2);

figure(4)
semilogx(f,20*log10([Force.SpecAtPes,Flutter.Spec,Sensor.Spec,RRO.Spec+eps,SpecALL]));
title('Dist data in frequency domain')
xlabel('Frequency [Hz]'), ylabel('Magnitude [dB]')
axis([1e1 1e4 -120 0])
legend('Force Dist at PES','Flutter Dist','Sensor Noise','RRO Dist','ALL')

% Disturbance and Noise in time domain
% Force Dist
tTD    = Force.DistT;
yTD    = Force.Dist;
tTDpes = Force.DistAtPesT;
yTDpes = Force.DistAtPes;
% Sensor Noise
tSN = Sensor.NoiseT;
ySN = Sensor.Noise;
% Flutter Dist
tFD    = Flutter.DistT;
yFD    = Flutter.Dist;
tFDpes = Flutter.DistAtPesT;
yFDpes = Flutter.DistAtPes;
% RRO Dist
tRD = RRO.DistT;
yRD = RRO.Dist;

figure(5)
subplot(411)
plot(tTDpes,yTDpes);
title('Torque Dist at PES')
xlabel('Time [s]'), ylabel('PES [track]')
%
subplot(412)
plot(tSN,ySN);
title('Sensor Noise')
xlabel('Time [s]'), ylabel('PES [track]')
%
subplot(413)
plot(tFD,yFD);
title('Flutter Dist')
xlabel('Time [s]'), ylabel('PES [track]')
%
subplot(414)
plot(tRD,yRD);
title('RRO Dist')
xlabel('Time [s]'), ylabel('PES [track]')
subplot(111)

yALL = yTDpes + ySN + yFDpes + yRD;
figure(6)
plot(tTDpes,yALL)
title('ALL Dist at PES')
xlabel('Time [s]'),ylabel('PES [track]')

% Relation between time domain and frequency domain
Ts   = PlantData.Ts;
Nfft = 2^12; % fft length

% Calc PSD
[g_all,ff] = psdcal(yALL,Nfft,Ts);
% [g_all,ff] = psdcal(yFDpes,Nfft,Ts);

figure(7)
semilogx(ff,20*log10(g_all)/2,f,20*log10(SpecALL),'r');
axis([1e1 1e4 -80 -20])
xlabel('Frequecy [Hz]'), ylabel('sqrt(PSD)')
legend('PSD of dist sequence','Dist data in freq. domain')

% save data
% save mainAllData
% save mainPlantData PlantData

%% EOF of main.m
